@@ -24,7 +24,7 @@
 /* -------------------------------------------------------------------- */
 
 #define HAVE_CXX
-#define USE_XPM
+#define HAVE_XPM
 #define USE_GL
 #define USE_UNSTABLE
 #define USE_BOMB
@@ -75,8 +75,11 @@ LockStruct  LockProcs[] =
 	"Shows Apollonian Circles", 0, NULL, NULL},
 #ifdef USE_GL
 	{"atlantis",
-	 18000, 4, 100, 6000, 64, 1.0, "",
+	 25000, 4, 100, 6000, 64, 1.0, "",
 	 "Shows moving sharks/whales/dolphin", 0, NULL, "#ifdef USE_GL"},
+	{"atunnels",
+	 25000, 1, 1, 400, 64, 1.0, "",
+	 "Shows a n OpenGL advanced tunnel screensaver", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"ball",
 	 10000, 10, 20, -100, 64, 1.0, "",
@@ -101,7 +104,7 @@ LockStruct  LockProcs[] =
 	 "Shows popping bubbles", 0, NULL, NULL},
 #if defined( USE_GL ) && defined( HAVE_CXX )
 	{"bubble3d",
-	 1000, 1, 2, 1, 64, 1.0, "",
+	 20000, 1, 2, 1, 64, 1.0, "",
 	 "Richard Jones's GL bubbles", 0, NULL, "#if defined( USE_GL ) && defined( HAVE_CXX )"},
 #endif
 	{"bug",
@@ -109,7 +112,7 @@ LockStruct  LockProcs[] =
 	 "Shows Palmiter's bug evolution and garden of Eden", 0, NULL, NULL},
 #ifdef USE_GL
 	{"cage",
-	 25000, 1, 1, 1, 64, 1.0, "",
+	 80000, 1, 1, 1, 64, 1.0, "",
 	 "Shows the Impossible Cage, an Escher-like GL scene", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"clock",
@@ -159,7 +162,7 @@ LockStruct  LockProcs[] =
 	 "Shows a fading plot of sine squared", 0, NULL, NULL},
 #ifdef USE_GL
 	{"fire",
-	 10000, 800, 1, 1, 64, 1.0, "",
+	 10000, 800, 1, 400, 64, 1.0, "",
 	 "Shows a 3D fire-like image", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"flag",
@@ -169,7 +172,7 @@ LockStruct  LockProcs[] =
 	 750000, 20, 10000, 1, 64, 1.0, "",
 	 "Shows cosmic flame fractals", 0, NULL, NULL},
 	{"flow",
-	 1000, 1024, 3000, 1, 64, 1.0, "",
+	 1000, 1024, 3000, -10, 64, 1.0, "",
 	 "Shows dynamic strange attractors", 0, NULL, NULL},
 	{"forest",
 	 400000, 100, 200, 1, 64, 1.0, "",
@@ -179,12 +182,12 @@ LockStruct  LockProcs[] =
 	 "Shows crashing spiral galaxies", 0, NULL, NULL},
 #ifdef USE_GL
 	{"gears",
-	 1000, 1, 2, 1, 64, 1.0, "",
+	 50000, 1, 2, 1, 64, 1.0, "",
 	 "Shows GL's gears", 0, NULL, "#ifdef USE_GL"},
 #endif
 #ifdef USE_GL
 	{"glplanet",
-	 1000, 1, 2, 1, 64, 1.0, "",
+	 15000, 1, 2, 1, 64, 1.0, "",
 	 "Animates texture mapped sphere (planet)", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"goop",
@@ -213,7 +216,7 @@ LockStruct  LockProcs[] =
 	 "Shows randomly appearing logos", 0, NULL, NULL},
 #if defined( USE_GL ) && defined( HAVE_CXX )
 	{"invert",
-	 100, 1, 1, 1, 64, 1.0, "",
+	 80000, 1, 1, 1, 64, 1.0, "",
 	 "Shows a sphere inverted without wrinkles", 0, NULL, "#if defined( USE_GL ) && defined( HAVE_CXX )"},
 #endif
         {"juggle",
@@ -274,13 +277,13 @@ LockStruct  LockProcs[] =
      "Shows a random maze and a depth first search solution", 0, NULL, NULL},
 #ifdef USE_GL
 	{"moebius",
-	 1000, 1, 1, 1, 64, 1.0, "",
+	 30000, 1, 1, 1, 64, 1.0, "",
 	 "Shows Moebius Strip II, an Escher-like GL scene with ants", 0, NULL, "#ifdef USE_GL"},
 	{(char *) "molecule",
 	 50000, 1, 20, 1, 64, 1.0, "",
 	 "Draws molecules", 0, NULL, "#ifdef USE_GL"},
 	{"morph3d",
-	 1000, 0, 1, 1, 64, 1.0, "",
+	 40000, 0, 1, 1, 64, 1.0, "",
 	 "Shows GL morphing polyhedra", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"mountain",
@@ -289,11 +292,14 @@ LockStruct  LockProcs[] =
 	{"munch",
 	 5000, 1, 7, 1, 64, 1.0, "",
 	 "Shows munching squares", 0, NULL, NULL},
+	{"nose",
+	 1000, 1, 1, 1, 64, 1.0, "",
+	 "Shows SGI Diatoms", 0, NULL, NULL},
 	{"nose",
 	 100000, 1, 1, 1, 64, 1.0, "",
 	 "Shows a man with a big nose runs around spewing out messages", 0, NULL, NULL},
 	{"pacman",
-	 100000, 10, 1, 0, 64, 1.0, "",
+	 10000, 10, 1, 0, 64, 1.0, "",
 	 "Shows Pacman(tm)", 0, NULL, NULL},
 	{"penrose",
 	 10000, 1, 1, -40, 64, 1.0, "",
@@ -301,6 +307,9 @@ LockStruct  LockProcs[] =
 	{"petal",
 	 10000, -500, 400, 1, 64, 1.0, "",
 	 "Shows various GCD Flowers", 0, NULL, NULL},
+	{"petri",
+	 10000, 1, 1, 4, 8, 1.0, "",
+	 "Shows a mold simulation in a petri dish", 0, NULL, NULL},
 #ifdef USE_GL
 	{"pipes",
 	 1000, 2, 5, 500, 64, 1.0, "",
@@ -326,12 +335,12 @@ LockStruct  LockProcs[] =
 	 "Shows Tom's Roto-Rooter", 0, NULL, NULL},
 #ifdef USE_GL
 	{"rubik",
-	 10000, -30, 5, -6, 64, 1.0, "",
+	 100000, -30, 5, -6, 64, 1.0, "",
 	 "Shows an auto-solving Rubik's Cube", 0, NULL, "#ifdef USE_GL"},
 #endif
 #ifdef USE_GL
 	{"sballs",
-	 10000, 0, 10, 400, 64, 1.0, "",
+	 40000, 0, 10, 400, 64, 1.0, "",
 	 "Balls spinning like crazy in GL", 0, NULL, "#ifdef USE_GL"},
 #endif
         {"scooter",
@@ -345,12 +354,12 @@ LockStruct  LockProcs[] =
 	 "Shows Sierpinski's triangle", 0, NULL, NULL},
 #ifdef USE_GL
 	{"sierpinski3d",
-         1000, 1, 2, 1, 64, 1.0, "",
+         15000, 1, 2, 1, 64, 1.0, "",
          "Shows GL's Sierpinski gasket", 0, NULL, "#ifdef USE_GL"},
 #endif
 #if defined(USE_GL) && defined( USE_UNSTABLE )
 	{"skewb",
-	 10000, -30, 5, 1, 64, 1.0, "",
+	 100000, -30, 5, 1, 64, 1.0, "",
 	 "Shows an auto-solving Skewb", 0, NULL, "#if defined(USE_GL) && defined( USE_UNSTABLE )"},
 #endif
 	{"slip",
@@ -375,7 +384,7 @@ LockStruct  LockProcs[] =
 	 "Shows colorful moving splines", 0, NULL, NULL},
 #ifdef USE_GL
 	{"sproingies",
-	 1000, 5, 0, 400, 64, 1.0, "",
+	 80000, 5, 0, 400, 64, 1.0, "",
 	 "Shows Sproingies!  Nontoxic.  Safe for pets and small children", 0, NULL, "#ifdef USE_GL"},
 	{"stairs",
 	 200000, 0, 1, 1, 64, 1.0, "",
@@ -392,11 +401,11 @@ LockStruct  LockProcs[] =
 	 "Shows strange attractors", 0, NULL, NULL},
 #ifdef USE_GL
 	{"superquadrics",
-	 1000, 25, 40, 1, 64, 1.0, "",
+	 40000, 25, 40, 1, 64, 1.0, "",
 	 "Shows 3D mathematical shapes", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"swarm",
-	 15000, -100, 1, -100, 64, 1.0, "",
+	 15000, -100, 1, -10, 64, 1.0, "",
 	 "Shows a swarm of bees following a wasp", 0, NULL, NULL},
 	{"swirl",
 	 5000, 5, 1, 1, 64, 1.0, "",
