@@ -42,6 +42,7 @@ static const char sccsid[] = "@(#)euler2d.c	5.00 2000/11/01 xlockmore";
  */
 
 #ifdef STANDALONE
+#define MODE_euler2d
 #define PROGCLASS "Euler2d"
 #define HACK_INIT init_euler2d
 #define HACK_DRAW draw_euler2d
@@ -481,7 +482,7 @@ ode_solve(euler2dstruct *sp)
   }
 }
 
-#define deallocate(p,t) if (p!=NULL) {(void) free((void *) p); p=(t*)NULL; }
+#define deallocate(p,t) if (p!=NULL) {free(p); p=(t*)NULL; }
 #define allocate(p,t,s) if ((p=(t*)malloc(sizeof(t)*s))==NULL)\
 {free_euler2d(sp);return;}
 
@@ -815,9 +816,9 @@ draw_euler2d(ModeInfo * mi)
 		if (MI_NPIXELS(mi) > 2){ /* render colour */
 			for (col = 0; col < MI_NPIXELS(mi); col++) {
 			  int start = col*n_non_vortex_segs/MI_NPIXELS(mi);
-			  int finish = (col+1)*n_non_vortex_segs/MI_NPIXELS(mi);
+			  int end = (col+1)*n_non_vortex_segs/MI_NPIXELS(mi);
 			  XSetForeground(display, gc, MI_PIXEL(mi, col));
-			  XDrawSegments(display, window, gc,sp->csegs+start, finish-start);
+			  XDrawSegments(display, window, gc,sp->csegs+start, end-start);
 			}
 			if (!sp->hide_vortex) {
 			  XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
@@ -863,7 +864,7 @@ release_euler2d(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_euler2d(&euler2ds[screen]);
-		(void) free((void *) euler2ds);
+		free(euler2ds);
 		euler2ds = (euler2dstruct *) NULL;
 	}
 }
