@@ -34,6 +34,7 @@ static const char sccsid[] = "@(#)flame.c	5.00 2000/11/01 xlockmore";
  */
 
 #ifdef STANDALONE
+#define MODE_flame
 #define PROGCLASS "Flame"
 #define HACK_INIT init_flame
 #define HACK_DRAW draw_flame
@@ -339,7 +340,7 @@ void
 release_flame(ModeInfo * mi)
 {
 	if (flames != NULL) {
-		(void) free((void *) flames);
+		free(flames);
 		flames = (flamestruct *) NULL;
 	}
 }
