@@ -2,7 +2,7 @@
 /* text3d --- Shows moving 3D texts */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)text3d.cc	5.01 2001/03/09 xlockmore";
+static const char sccsid[] = "@(#)text3d.cc	5.02 2001/11/09 xlockmore";
 
 #endif
 
@@ -33,6 +33,8 @@ static const char sccsid[] = "@(#)text3d.cc	5.01 2001/03/09 xlockmore";
  * Eric Lassauge  (October-28-1999)
  *
  * Revision History:
+ * 09-Nov-2001: Removed BLANK and various cleanups
+ *              Added Wander animation
  * 09-Mar-2001: Removed an erroneous PushMatrix !!!
  * 01-Nov-2000: Allocation checks
  * 28-Oct-1999: fixes from Jouk "I play with every mode" Jansen.
@@ -57,18 +59,20 @@ static const char sccsid[] = "@(#)text3d.cc	5.01 2001/03/09 xlockmore";
  *          
  */
 
-#ifdef STANDALONE
-#define PROGCLASS "Text3d"
-#define HACK_INIT init_text3d
-#define HACK_DRAW draw_text3d
-#define text3d_opts xlockmore_opts
-#define DEFAULTS "*delay: 100000 \n" \
- "*ncolors: 64 \n" \
- "*font: \n" \
- "*text: \n" \
- "*filename: \n" \
- "*fortunefile: \n" \
- "*program: \n"
+#ifdef STANDALONE	/* xscreensaver mode: can't work ! */
+#define MODE_text3d
+#define PROGCLASS 	"Text3d"
+#define HACK_INIT 	init_text3d
+#define HACK_DRAW 	draw_text3d
+#define HACK_RESHAPE 	reshape_text3d
+#define text3d_opts 	xlockmore_opts
+#define DEFAULTS 	"*delay: 	100000 \n" \
+ 			"*ncolors: 	    64 \n" \
+ 			"*font: 	       \n" \
+ 			"*text: 	       \n" \
+ 			"*filename: 	       \n" \
+ 			"*fortunefile: 	       \n" \
+ 			"*program: 	       \n"
 
 extern "C"
 {
@@ -76,7 +80,7 @@ extern "C"
 }
 #else				/* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
-#include "vis.h"
+#include "visgl.h"
 #ifdef HAS_MMOV
 #undef error
 #endif
@@ -98,16 +102,6 @@ extern "C"
 #include "text3d.h"
 #include <GL/glu.h>
 
-/* #define USE_BLANK *//* This is really bad when debugging. */
-#ifdef USE_BLANK	/* if the module cannot create the font struct
-			 * then use blank mode instead
-			 */
-extern "C" { void init_blank(ModeInfo * mi); }
-extern "C" { void draw_blank(ModeInfo * mi); }
-extern "C" { void release_blank(ModeInfo * mi); }
-extern "C" { void refresh_blank(ModeInfo * mi); }
-#endif
-
 /* Yes, it's an ugly mix of 'C' and 'C++' functions */
 extern "C" { void init_text3d(ModeInfo * mi); }
 extern "C" { void draw_text3d(ModeInfo * mi); }
@@ -120,22 +114,10 @@ extern "C" { void refresh_text3d(ModeInfo * mi); }
 /* Windows95 in c:\windows\fonts\arial.ttf */
 
 #ifndef DEF_TTFONT
-#if 0
-#if 1
-#define DEF_TTFONT "/usr/lib/X11/xlock/fonts/arial.ttf"
-#else
-#define DEF_TTFONT "@PREFIX@/lib/X11/xlock/fonts/arial.ttf"
-#endif
-#else
 /* Directory of only *.ttf */
 /* symbol.ttf and wingding.ttf should be excluded or it may core dump */
 /* can be excluded if gltt is modified see README */
-#if 1
 #define DEF_TTFONT "/usr/lib/X11/xlock/fonts/"
-#else
-#define DEF_TTFONT "@PREFIX@/lib/X11/xlock/fonts/"
-#endif
-#endif
 #endif
 
 #define DEF_EXTRUSION  "25.0"
@@ -218,6 +200,7 @@ static void t3d_anim_rotatexy(text3dstruct * tp);
 static void t3d_anim_rotateyz(text3dstruct * tp);
 static void t3d_anim_frequency(text3dstruct * tp);
 static void t3d_anim_amplitude(text3dstruct * tp);
+static void t3d_anim_wander(text3dstruct * tp);
 static char *fontfile = (char *) NULL;
 
 #ifdef __cplusplus
@@ -237,6 +220,7 @@ static t3dAnimProc anim_array[] =
 	t3d_anim_rotateyz,
 	t3d_anim_frequency,
 	t3d_anim_amplitude,
+	t3d_anim_wander,
 };
 
 static char * anim_names[] =
@@ -253,6 +237,7 @@ static char * anim_names[] =
 	(char *) "RotateYZ",
 	(char *) "Frequency",	/* needs -rot_frequency /= 0.0 */
 	(char *) "Amplitude",	/* and   -rot_amplitude /= 0.0 */
+	(char *) "Wander",
 	(char *) NULL
 };
 
@@ -272,6 +257,10 @@ static int anims=sizeof anim_array / sizeof anim_array[0] ;
  *-----------------------------------------------------------------------------
  */
 
+/* Select light stuff with the following defines */
+#define TWO_LIGHTS
+#define ALL_STUFF
+//#define DIFFUSE_COLOR
 
 #ifdef DIFFUSE_COLOR
 static void
@@ -400,6 +389,7 @@ public:
  *-----------------------------------------------------------------------------
  */
 
+/* defines for min/max/evolution factor of animations */
 #define FAC_CAMERA	1.15
 #define MAX_CAMERA	5.00
 
@@ -410,7 +400,7 @@ public:
 #define FAC_FREQ	0.15
 #define FAC_AMPL	1.5
 
-#define FAC_RAND	25
+#define FAC_RAND	15
 
 #ifdef __cplusplus
 extern "C" {
@@ -593,11 +583,30 @@ static void
 static void
  t3d_anim_fullrandom(text3dstruct * tp)
 {
-    if (NRAND(100) < FAC_RAND || tp->animation == 1)
+    static int animation=NRAND(anims);
+    if (NRAND(100) < FAC_RAND/5 || animation <= 1)
     {
-      	tp->animation = NRAND(anims);
+    	/* change animation */
+      	animation = NRAND(anims);
     }
-    anim_array[tp->animation](tp);
+    anim_array[animation](tp);
+}
+
+static void
+ t3d_anim_wander(text3dstruct * tp)
+{
+        static int frame = 0;
+	GLfloat x, y, z;
+	#define SINOID(SCALE,SIZE) \
+	 ((((1 + sin((frame * (SCALE)) / 2 * M_PI)) / 2.0) * (SIZE)) - (SIZE)/2)
+
+	x = SINOID(0.061, angle_speed);
+	y = SINOID(0.083, angle_speed * 2.0);
+	z = SINOID(0.075, MAX_CAMERA * 10.0);
+	frame++;
+    	tp->phi   += tp->direction * x;
+    	tp->theta += tp->direction * y;
+        tp->camera_dist += tp->direction * z;
 }
 
 #ifdef __cplusplus
@@ -613,8 +622,8 @@ static void
  *-----------------------------------------------------------------------------
  */
 
-static void
- Reshape(ModeInfo * mi, int width, int height)
+void
+ reshape_text3d(ModeInfo * mi, int width, int height)
 {
     text3dstruct *tp = &text3d[MI_SCREEN(mi)];
 
@@ -734,7 +743,7 @@ static void
     }
 
     if (!nosplit)
-	(void) free((void *) c_text);
+	free(c_text);
     if (size_x == 0.0)
     {
 	(void) fprintf(stderr, "Please give something to draw !\n");
@@ -770,8 +779,6 @@ static void
 	}
     }
 
-#define TWO_LIGHTS
-#define ALL_STUFF
 
 #ifdef ALL_STUFF
     float front_emission[4] = {0.1, 0.1, 0.1, 0};
@@ -1086,13 +1093,31 @@ void
 		   MI_NAME(mi), tp->animation, anim_names[tp->animation+1]);
     }
 
-
     tp->counter = 0;
 
+	fontfile = getModeFont(mode_font);
+	if (!fontfile) {
+		MI_CLEARWINDOW(mi);
+		release_text3d(mi);
+		return;
+    }
+    tp->face = new FTFace;
+    if (!tp->face || !tp->face->open(fontfile)) {
+		(void) fprintf(stderr, "%s: unable to open True Type font %s!\n", MI_NAME(mi), fontfile);
+		MI_CLEARWINDOW(mi);
+		release_text3d(mi);
+		return;
+    }
+    if (MI_IS_DEBUG(mi)) {
+		(void) fprintf(stderr,
+			"%s:\n\tfontfile=%s .\n", MI_NAME(mi), fontfile);
+    }
+
+    /* Do not free fontfile getModeFont handles potential leak */
     if ((tp->glx_context = init_GL(mi)) != NULL)
     {
 
-	Reshape(mi, MI_WIDTH(mi), MI_HEIGHT(mi));
+	reshape_text3d(mi, MI_WIDTH(mi), MI_HEIGHT(mi));
 	/*glDrawBuffer(GL_BACK); */
 	if (MI_IS_DEBUG(mi))
 	{
@@ -1110,33 +1135,6 @@ void
     {
 	MI_CLEARWINDOW(mi);
     }
-	fontfile = getModeFont(mode_font);
-	if (!fontfile) {
-		release_text3d(mi);
-#ifdef USE_BLANK
-		(void) fprintf(stderr,
-			"%s: jumping to 'blank' mode.\n", MI_NAME(mi));
-		init_blank(mi);
-#endif
-		return;
-    }
-    tp->face = new FTFace;
-    if (!tp->face || !tp->face->open(fontfile)) {
-		(void) fprintf(stderr, "%s: unable to open True Type font %s !\n", MI_NAME(mi), fontfile);
-		release_text3d(mi);
-#ifdef USE_BLANK
-		(void) fprintf(stderr,
-				"%s: jumping to 'blank' mode.\n", MI_NAME(mi));
-		init_blank(mi);
-#endif
-		return;
-    }
-    if (MI_IS_DEBUG(mi)) {
-		(void) fprintf(stderr,
-			"%s:\n\tfontfile=%s .\n", MI_NAME(mi), fontfile);
-    }
-
-    /* Do not free fontfile getModeFont handles potential leak */
 
     /* Initialize displayed string */
     tp->words_start = tp->words =
@@ -1163,9 +1161,6 @@ void
     text3dstruct *tp;
 
     if (text3d == NULL) {
-#ifdef USE_BLANK
-	  draw_blank(mi);
-#endif
 	  return;
 	}
     tp = &text3d[MI_SCREEN(mi)];
@@ -1204,10 +1199,6 @@ void
 		       MI_NAME(mi), tp->camera_dist, tp->theta, tp->phi,
 		       tp->extrusion, tp->rampl,tp->rfreq,tp->direction);
     }
-
-/*
-    glXSwapBuffers(display, window);
-*/
 }
 
 /*
@@ -1230,13 +1221,9 @@ void
 	    if (tp->face)
 		delete tp->face;
 	}
-	(void) free((void *) text3d);
+	free(text3d);
 	text3d = (text3dstruct *) NULL;
     }
-#ifdef USE_BLANK
-    else
-	release_blank(mi);
-#endif
     FreeAllGL(mi);
 }
 
@@ -1252,9 +1239,6 @@ void
     text3dstruct *tp;
 
     if (text3d == NULL) {
-#ifdef USE_BLANK
-	  refresh_blank(mi);
-#endif
 	  return;
 	}
     tp = &text3d[MI_SCREEN(mi)];
