@@ -15,14 +15,10 @@
  */
 
 #ifdef USE_MAGICK
-
-#include <stdio.h>
 #include <time.h>
 #include <sys/types.h>
 #include <magick/api.h>
 
-#include "xlock.h"
-#include "iostuff.h"
 #include "xlockimage.h"
 
 #define MagickColorError   1
