@@ -485,17 +485,18 @@ extern void release_last_mode(ModeInfo *);
 /* -------------------------------------------------------------------- */
 
 /* if you just want the blank mode... how sad! */
-#ifndef BLANK_ONLY 
+#ifndef BLANK_ONLY
 /* comment out following defines to remove modes */
 #ifdef USE_GL
 #define MODE_cage
 #define MODE_fire
 #define MODE_gears
+#define MODE_glplanet
 #define MODE_lament
 #define MODE_moebius
 #define MODE_molecule
 #define MODE_morph3d
-#define MODE_glplanet
+#define MODE_noof
 #define MODE_rubik
 #define MODE_sierpinski3d
 #define MODE_sballs
@@ -505,7 +506,12 @@ extern void release_last_mode(ModeInfo *);
 #ifdef USE_UNSTABLE
 #define MODE_skewb /* under development */
 #endif
+#ifdef USE_RETIRED
+#define MODE_cartoon /* retired mode */
+#define MODE_kaleid2 /* retired mode */
+#endif
 #define MODE_atlantis
+#define MODE_atunnels
 #define MODE_bubble3d
 #define MODE_pipes
 #define MODE_sproingies
@@ -597,6 +603,7 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_pacman
 #define MODE_penrose
 #define MODE_petal
+#define MODE_petri
 #define MODE_polyominoes
 #define MODE_puzzle
 #define MODE_pyro
@@ -664,6 +671,15 @@ extern ModeHook change_atlantis;
 extern ModeSpecOpt atlantis_opts;
 #endif
 
+#ifdef MODE_atunnels
+extern ModeHook init_atunnels;
+extern ModeHook draw_atunnels;
+extern ModeHook release_atunnels;
+extern ModeHook refresh_atunnels;
+extern ModeHook change_atunnels;
+extern ModeSpecOpt atunnels_opts;
+#endif
+
 #ifdef MODE_ball
 extern ModeHook init_ball;
 extern ModeHook draw_ball;
@@ -752,6 +768,14 @@ extern ModeHook change_cage;
 extern ModeSpecOpt cage_opts;
 #endif
 
+#ifdef MODE_cartoon
+extern ModeHook init_cartoon;
+extern ModeHook draw_cartoon;
+extern ModeHook release_cartoon;
+extern ModeHook refresh_cartoon;
+extern ModeSpecOpt cartoon_opts;
+#endif
+
 #ifdef MODE_clock
 extern ModeHook init_clock;
 extern ModeHook draw_clock;
@@ -1015,7 +1039,7 @@ extern ModeHook draw_juggle;
 extern ModeHook release_juggle;
 extern ModeSpecOpt juggle_opts;
 #endif
- 
+
 #ifdef MODE_julia
 extern ModeHook init_julia;
 extern ModeHook draw_julia;
@@ -1024,6 +1048,14 @@ extern ModeHook refresh_julia;
 extern ModeSpecOpt julia_opts;
 #endif
 
+#ifdef MODE_kaleid2
+extern ModeHook init_kaleid2;
+extern ModeHook draw_kaleid2;
+extern ModeHook release_kaleid2;
+extern ModeHook refresh_kaleid2;
+extern ModeSpecOpt kaleid2_opts;
+#endif
+
 #ifdef MODE_kaleid
 extern ModeHook init_kaleid;
 extern ModeHook draw_kaleid;
@@ -1192,6 +1224,13 @@ extern ModeHook release_munch;
 extern ModeSpecOpt munch_opts;
 #endif
 
+#ifdef MODE_noof
+extern ModeHook init_noof;
+extern ModeHook draw_noof;
+extern ModeHook release_noof;
+extern ModeSpecOpt noof_opts;
+#endif
+
 #ifdef MODE_nose
 extern ModeHook init_nose;
 extern ModeHook draw_nose;
@@ -1205,6 +1244,7 @@ extern ModeHook init_pacman;
 extern ModeHook draw_pacman;
 extern ModeHook release_pacman;
 extern ModeHook refresh_pacman;
+extern ModeHook change_pacman;
 extern ModeSpecOpt pacman_opts;
 #endif
 
@@ -1227,6 +1267,14 @@ extern ModeHook refresh_petal;
 extern ModeSpecOpt petal_opts;
 #endif
 
+#ifdef MODE_petri
+extern ModeHook init_petri;
+extern ModeHook draw_petri;
+extern ModeHook release_petri;
+extern ModeHook refresh_petri;
+extern ModeSpecOpt petri_opts;
+#endif
+
 #ifdef MODE_pipes
 extern ModeHook init_pipes;
 extern ModeHook draw_pipes;
